import React, { useState, useEffect } from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { Form, Pagination, Button, Icon, message, Modal, Table, Select, Input, DatePicker } from 'antd';
import router from 'umi/router';
import moment from 'moment';
import className from 'classnames';
import Cell from '../../components/Cell';
import styles from './style.less';
import { fetch, apis } from '../../utils/request';
import request from '../../utils/request';
import AuthButton from '@/components/AuthButton';
import { regFenToYuan } from '@/utils/money';

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;

function header(props) {
    // 获取初始化数据
    const [data, setData] = useState({})
    const [demandIdList, setDemandIdList] = useState([])
    const orgId = props.orgId || ''
    useEffect(() => {
        getList({ pageNum: 1, pageSize: 10, orderType: 'recharge' });
    }, [])

    // 查询列表
    const getList = (params) => {
        request({ ...apis.fund.taOrgOrder, params: { ...params, orgId } }).then((data) => {
            console.log(data)
            setData(data)
        })
    }


    // 提交事件
    const handleSubmit = (e, props) => {
        e.preventDefault();
        props.form.validateFields((err, values) => {
            if (!err) {
                let { LocalDate, ...submitValue } = values
                if (null != LocalDate && LocalDate.length > 0) {
                    const [startDate, endDate] = LocalDate
                    submitValue.startDate = moment(startDate).format('YYYY-MM-DD');
                    submitValue.endDate = moment(endDate).format('YYYY-MM-DD');
                } else {
                    submitValue.startDate = null
                    submitValue.endDate = null
                }
                getList({ pageNum: 1, pageSize: 10, orderType: 'recharge', ...submitValue })
            }
        });
    }

    const changePageNum = (pageNumber) => {
        let { LocalDate, ...submitValue } = props.form.getFieldsValue()
        if (null != LocalDate && LocalDate.length > 0) {
            const [startDate, endDate] = LocalDate
            submitValue.startDate = moment(startDate).format('YYYY-MM-DD');
            submitValue.endDate = moment(endDate).format('YYYY-MM-DD');
        } else {
            submitValue.startDate = null
            submitValue.endDate = null
        }
        getList({ pageNum: pageNumber, pageSize: 10, orderType: 'recharge', ...submitValue })
    }

    /**
     *
     *
     * @param {*} props
     * @returns
     */
    const columns = [
        {
            title: '订单编号',
            dataIndex: 'tradeNo',
            key: 'tradeNo',
            align: 'center',
        },
        {
            title: '充值组织',
            dataIndex: 'miniAppName',
            key: 'miniAppName',
            align: 'center',
        },
        {
            title: '充值金额',
            dataIndex: 'amount',
            key: 'amount',
            align: 'center',
            render: (x, row) => <span>{regFenToYuan(x)}</span>

        },
        {
            title: '充值方式',
            dataIndex: 'isOffline',
            key: 'isOffline',
            align: 'center',
            render: (x, row) => <><span>{row.isOffline ? '运营手动充值' : '业务线上充值'}</span></>
        },
        {
            title: '下单时间',
            dataIndex: 'createDate',
            key: 'createDate',
            align: 'center',
            render: (x, row) => <><span>{`${moment(row.createDate).format('YYYY-MM-DD HH:mm:ss')}`}</span></>,
        },
        {
            title: '充值凭证',
            dataIndex: 'orgName',
            key: 'orgName',
            align: 'center',
        },
        {
            title: '充值状态',
            dataIndex: 'tradingStatus',
            key: 'tradingStatus',
            align: 'center',
            render: (x, row) => <><span>{row.tradingStatus == '0' ? '待支付' : row.tradingStatus == '1' ? '已支付' : '已超时'}</span></>
        },
        {
            title: '支付时间',
            dataIndex: 'payDate',
            key: 'payDate',
            align: 'center',
            render: (x, row) => <><span>{row.payDate ? `${moment(row.payDate).format('YYYY-MM-DD HH:mm:ss')}` : ''}</span></>,
        },

    ];
    function handleReset() {
        props.form.resetFields();
        getList({ pageNum: 1, pageSize: 10, orderType: 'recharge' })
    }
    // 导出
    const exportList = () => {
        let { LocalDate, ...submitValue } = props.form.getFieldsValue()
        if (null != LocalDate && LocalDate.length > 0) {
            const [startDate, endDate] = LocalDate
            submitValue.startDate = moment(startDate).format('YYYY-MM-DD');
            submitValue.endDate = moment(endDate).format('YYYY-MM-DD');
        } else {
            submitValue.startDate = null
            submitValue.endDate = null
        }
        request({ ...apis.fund.rechargeOrderExport, params: { orderType: 'recharge', orgId, ...submitValue } }).then(data => {
            if (!data) {
                return
            }
            const url = window.URL.createObjectURL(new Blob([data]))
            const link = document.createElement('a')
            link.style.display = 'none'
            link.href = url
            link.setAttribute('download', '充值订单表.xlsx')
            document.body.append(link)
            link.click()
        }).catch()
    }
    const { getFieldDecorator } = props.form
    return (

        <>
            <Form layout="inline" onSubmit={e => handleSubmit(e, props)} style={{ marginBottom: '16px' }}>
                <Form.Item>
                    {getFieldDecorator('tradeNo')(
                        <Input
                            prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
                            placeholder="订单编号"
                        />,
                    )}
                </Form.Item>
                <Form.Item>
                    {getFieldDecorator('miniAppName')(
                        <Input
                            prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
                            placeholder="充值组织"
                        />,
                    )}
                </Form.Item>
                <Form.Item>
                    <span style={{ marginRight: '10px' }}>支付时间段：</span>
                    {getFieldDecorator('LocalDate')(
                        <RangePicker placeholder={['开始时间', '结束时间']} />
                    )}
                </Form.Item>
                <Form.Item>
                    {getFieldDecorator('isOffline')(
                        <Select style={{ width: '180px' }} placeholder="充值方式">
                            <Select.Option value="">全部</Select.Option>
                            <Select.Option value="0">业务线上充值</Select.Option>
                            <Select.Option value="1">运营手动充值</Select.Option>
                        </Select>,
                    )}
                </Form.Item>
                <Form.Item>
                    {getFieldDecorator('tradingStatus')(
                        <Select style={{ width: '180px' }} placeholder="充值状态">
                            <Select.Option value="">全部</Select.Option>
                            <Select.Option value="0">待支付</Select.Option>
                            <Select.Option value="1">已支付</Select.Option>
                            <Select.Option value="2">已超时</Select.Option>
                        </Select>,
                    )}
                </Form.Item>
                <Form.Item>
                    <Button type="primary" htmlType="submit" className={styles.searchBtn}>
                        搜索
          </Button>
                    <Button style={{ marginLeft: 8 }} onClick={handleReset}>
                        重置
          </Button>
                </Form.Item>
            </Form>
            <div>
                <Button type="danger" style={{ float: 'right', marginBottom: '20px', zIndex: 1 }} onClick={() => exportList()} >导出</Button>
            </div>
            <Table rowKey={r => r.tradeNo} dataSource={data.records} columns={columns} pagination={false} />
            <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
                <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
            </div>
        </>
    )
}
const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader